"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .messagetemplatedto import MessageTemplateDto, MessageTemplateDtoTypedDict
from .stepfilterdto import StepFilterDto, StepFilterDtoTypedDict
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ActivityNotificationStepResponseDtoReplyCallbackTypedDict(TypedDict):
    r"""Reply callback settings"""


class ActivityNotificationStepResponseDtoReplyCallback(BaseModel):
    r"""Reply callback settings"""


class ControlVariablesTypedDict(TypedDict):
    r"""Control variables"""


class ControlVariables(BaseModel):
    r"""Control variables"""


class ActivityNotificationStepResponseDtoMetadataTypedDict(TypedDict):
    r"""Metadata for the workflow step"""


class ActivityNotificationStepResponseDtoMetadata(BaseModel):
    r"""Metadata for the workflow step"""


class IssuesTypedDict(TypedDict):
    r"""Step issues"""


class Issues(BaseModel):
    r"""Step issues"""


class ActivityNotificationStepResponseDtoTypedDict(TypedDict):
    id: str
    r"""Unique identifier of the step"""
    active: bool
    r"""Whether the step is active or not"""
    filters: List[StepFilterDtoTypedDict]
    r"""Filter criteria for the step"""
    template_id: str
    r"""The identifier for the template associated with this step"""
    reply_callback: NotRequired[
        ActivityNotificationStepResponseDtoReplyCallbackTypedDict
    ]
    r"""Reply callback settings"""
    control_variables: NotRequired[ControlVariablesTypedDict]
    r"""Control variables"""
    metadata: NotRequired[ActivityNotificationStepResponseDtoMetadataTypedDict]
    r"""Metadata for the workflow step"""
    issues: NotRequired[IssuesTypedDict]
    r"""Step issues"""
    template: NotRequired[MessageTemplateDtoTypedDict]
    r"""Optional template for the step"""
    variants: NotRequired[List[ActivityNotificationStepResponseDtoTypedDict]]
    r"""Variants of the step"""
    name: NotRequired[str]
    r"""The name of the step"""
    parent_id: NotRequired[Nullable[str]]
    r"""The unique identifier for the parent step"""


class ActivityNotificationStepResponseDto(BaseModel):
    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""Unique identifier of the step"""

    active: bool
    r"""Whether the step is active or not"""

    filters: List[StepFilterDto]
    r"""Filter criteria for the step"""

    template_id: Annotated[str, pydantic.Field(alias="_templateId")]
    r"""The identifier for the template associated with this step"""

    reply_callback: Annotated[
        Optional[ActivityNotificationStepResponseDtoReplyCallback],
        pydantic.Field(alias="replyCallback"),
    ] = None
    r"""Reply callback settings"""

    control_variables: Annotated[
        Optional[ControlVariables], pydantic.Field(alias="controlVariables")
    ] = None
    r"""Control variables"""

    metadata: Optional[ActivityNotificationStepResponseDtoMetadata] = None
    r"""Metadata for the workflow step"""

    issues: Optional[Issues] = None
    r"""Step issues"""

    template: Optional[MessageTemplateDto] = None
    r"""Optional template for the step"""

    variants: Optional[List[ActivityNotificationStepResponseDto]] = None
    r"""Variants of the step"""

    name: Optional[str] = None
    r"""The name of the step"""

    parent_id: Annotated[OptionalNullable[str], pydantic.Field(alias="_parentId")] = (
        UNSET
    )
    r"""The unique identifier for the parent step"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "replyCallback",
            "controlVariables",
            "metadata",
            "issues",
            "template",
            "variants",
            "name",
            "_parentId",
        ]
        nullable_fields = ["_parentId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ProvidersIDEnum(str, Enum):
    r"""Provider ID of the job"""

    EMAILJS = "emailjs"
    MAILGUN = "mailgun"
    MAILJET = "mailjet"
    MANDRILL = "mandrill"
    NODEMAILER = "nodemailer"
    POSTMARK = "postmark"
    SENDGRID = "sendgrid"
    SENDINBLUE = "sendinblue"
    SES = "ses"
    NETCORE = "netcore"
    INFOBIP_EMAIL = "infobip-email"
    RESEND = "resend"
    PLUNK = "plunk"
    MAILERSEND = "mailersend"
    MAILTRAP = "mailtrap"
    CLICKATELL = "clickatell"
    OUTLOOK365 = "outlook365"
    NOVU_EMAIL = "novu-email"
    SPARKPOST = "sparkpost"
    EMAIL_WEBHOOK = "email-webhook"
    BRAZE = "braze"
    NEXMO = "nexmo"
    PLIVO = "plivo"
    SMS77 = "sms77"
    SMS_CENTRAL = "sms-central"
    SNS = "sns"
    TELNYX = "telnyx"
    TWILIO = "twilio"
    GUPSHUP = "gupshup"
    FIRETEXT = "firetext"
    INFOBIP_SMS = "infobip-sms"
    BURST_SMS = "burst-sms"
    BULK_SMS = "bulk-sms"
    ISEND_SMS = "isend-sms"
    FORTY_SIX_ELKS = "forty-six-elks"
    KANNEL = "kannel"
    MAQSAM = "maqsam"
    TERMII = "termii"
    AFRICAS_TALKING = "africas-talking"
    NOVU_SMS = "novu-sms"
    SENDCHAMP = "sendchamp"
    GENERIC_SMS = "generic-sms"
    CLICKSEND = "clicksend"
    BANDWIDTH = "bandwidth"
    MESSAGEBIRD = "messagebird"
    SIMPLETEXTING = "simpletexting"
    AZURE_SMS = "azure-sms"
    RING_CENTRAL = "ring-central"
    BREVO_SMS = "brevo-sms"
    EAZY_SMS = "eazy-sms"
    MOBISHASTRA = "mobishastra"
    AFRO_MESSAGE = "afro-message"
    UNIFONIC = "unifonic"
    SMSMODE = "smsmode"
    IMEDIA = "imedia"
    SINCH = "sinch"
    ISENDPRO_SMS = "isendpro-sms"
    FCM = "fcm"
    APNS = "apns"
    EXPO = "expo"
    ONE_SIGNAL = "one-signal"
    PUSHPAD = "pushpad"
    PUSH_WEBHOOK = "push-webhook"
    PUSHER_BEAMS = "pusher-beams"
    APPIO = "appio"
    NOVU = "novu"
    SLACK = "slack"
    DISCORD = "discord"
    MSTEAMS = "msteams"
    MATTERMOST = "mattermost"
    RYVER = "ryver"
    ZULIP = "zulip"
    GRAFANA_ON_CALL = "grafana-on-call"
    GETSTREAM = "getstream"
    ROCKET_CHAT = "rocket-chat"
    WHATSAPP_BUSINESS = "whatsapp-business"
    CHAT_WEBHOOK = "chat-webhook"
    NOVU_SLACK = "novu-slack"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .timedconfig import TimedConfig, TimedConfigTypedDict
from enum import Enum
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DigestTimedMetadataUnit(str, Enum):
    SECONDS = "seconds"
    MINUTES = "minutes"
    HOURS = "hours"
    DAYS = "days"
    WEEKS = "weeks"
    MONTHS = "months"


class DigestTimedMetadataType(str, Enum):
    TIMED = "timed"


class DigestTimedMetadataTypedDict(TypedDict):
    type: DigestTimedMetadataType
    amount: NotRequired[float]
    unit: NotRequired[DigestTimedMetadataUnit]
    digest_key: NotRequired[str]
    timed: NotRequired[TimedConfigTypedDict]


class DigestTimedMetadata(BaseModel):
    type: DigestTimedMetadataType

    amount: Optional[float] = None

    unit: Optional[DigestTimedMetadataUnit] = None

    digest_key: Annotated[Optional[str], pydantic.Field(alias="digestKey")] = None

    timed: Optional[TimedConfig] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .credentialsdto import CredentialsDto, CredentialsDtoTypedDict
from .stepfilterdto import StepFilterDto, StepFilterDtoTypedDict
from enum import Enum
from novu_py.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateIntegrationRequestDtoChannel(str, Enum):
    r"""The channel type for the integration"""

    IN_APP = "in_app"
    EMAIL = "email"
    SMS = "sms"
    CHAT = "chat"
    PUSH = "push"


class ConfigurationsTypedDict(TypedDict):
    r"""Configurations for the integration"""


class Configurations(BaseModel):
    r"""Configurations for the integration"""


class CreateIntegrationRequestDtoTypedDict(TypedDict):
    provider_id: str
    r"""The provider ID for the integration"""
    channel: CreateIntegrationRequestDtoChannel
    r"""The channel type for the integration"""
    name: NotRequired[str]
    r"""The name of the integration"""
    identifier: NotRequired[str]
    r"""The unique identifier for the integration"""
    environment_id: NotRequired[str]
    r"""The ID of the associated environment"""
    credentials: NotRequired[CredentialsDtoTypedDict]
    r"""The credentials for the integration"""
    active: NotRequired[bool]
    r"""If the integration is active, the validation on the credentials field will run"""
    check: NotRequired[bool]
    r"""Flag to check the integration status"""
    conditions: NotRequired[List[StepFilterDtoTypedDict]]
    r"""Conditions for the integration"""
    configurations: NotRequired[ConfigurationsTypedDict]
    r"""Configurations for the integration"""


class CreateIntegrationRequestDto(BaseModel):
    provider_id: Annotated[str, pydantic.Field(alias="providerId")]
    r"""The provider ID for the integration"""

    channel: CreateIntegrationRequestDtoChannel
    r"""The channel type for the integration"""

    name: Optional[str] = None
    r"""The name of the integration"""

    identifier: Optional[str] = None
    r"""The unique identifier for the integration"""

    environment_id: Annotated[Optional[str], pydantic.Field(alias="_environmentId")] = (
        None
    )
    r"""The ID of the associated environment"""

    credentials: Optional[CredentialsDto] = None
    r"""The credentials for the integration"""

    active: Optional[bool] = None
    r"""If the integration is active, the validation on the credentials field will run"""

    check: Optional[bool] = None
    r"""Flag to check the integration status"""

    conditions: Optional[List[StepFilterDto]] = None
    r"""Conditions for the integration"""

    configurations: Optional[Configurations] = None
    r"""Configurations for the integration"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .grouppreferencefilterdto import (
    GroupPreferenceFilterDto,
    GroupPreferenceFilterDtoTypedDict,
)
from .workflowpreferencerequestdto import (
    WorkflowPreferenceRequestDto,
    WorkflowPreferenceRequestDtoTypedDict,
)
from novu_py.types import BaseModel
from typing import List, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


UpdateTopicSubscriptionRequestDtoPreferencesTypedDict = TypeAliasType(
    "UpdateTopicSubscriptionRequestDtoPreferencesTypedDict",
    Union[
        WorkflowPreferenceRequestDtoTypedDict, GroupPreferenceFilterDtoTypedDict, str
    ],
)


UpdateTopicSubscriptionRequestDtoPreferences = TypeAliasType(
    "UpdateTopicSubscriptionRequestDtoPreferences",
    Union[WorkflowPreferenceRequestDto, GroupPreferenceFilterDto, str],
)


class UpdateTopicSubscriptionRequestDtoTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The name of the subscription"""
    preferences: NotRequired[
        List[UpdateTopicSubscriptionRequestDtoPreferencesTypedDict]
    ]
    r"""The preferences of the topic. Can be a simple workflow ID string, workflow preference object, or group filter object"""


class UpdateTopicSubscriptionRequestDto(BaseModel):
    name: Optional[str] = None
    r"""The name of the subscription"""

    preferences: Optional[List[UpdateTopicSubscriptionRequestDtoPreferences]] = None
    r"""The preferences of the topic. Can be a simple workflow ID string, workflow preference object, or group filter object"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WorkflowPreferenceDtoTypedDict(TypedDict):
    enabled: NotRequired[bool]
    r"""A flag specifying if notification delivery is enabled for the workflow. If true, notification delivery is enabled by default for all channels. This setting can be overridden by the channel preferences."""
    read_only: NotRequired[bool]
    r"""A flag specifying if the preference is read-only. If true, the preference cannot be changed by the Subscriber."""


class WorkflowPreferenceDto(BaseModel):
    enabled: Optional[bool] = True
    r"""A flag specifying if notification delivery is enabled for the workflow. If true, notification delivery is enabled by default for all channels. This setting can be overridden by the channel preferences."""

    read_only: Annotated[Optional[bool], pydantic.Field(alias="readOnly")] = False
    r"""A flag specifying if the preference is read-only. If true, the preference cannot be changed by the Subscriber."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .triggereventrequestdto import (
    TriggerEventRequestDto,
    TriggerEventRequestDtoTypedDict,
)
from novu_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class BulkTriggerEventDtoTypedDict(TypedDict):
    events: List[TriggerEventRequestDtoTypedDict]


class BulkTriggerEventDto(BaseModel):
    events: List[TriggerEventRequestDto]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict
from typing_extensions import Annotated, TypedDict


class GetContextResponseDtoTypedDict(TypedDict):
    type: str
    r"""Context type (e.g., tenant, app, workspace)"""
    id: str
    r"""Unique identifier for this context"""
    data: Dict[str, Any]
    r"""Custom data associated with this context"""
    created_at: str
    r"""Creation timestamp"""
    updated_at: str
    r"""Last update timestamp"""


class GetContextResponseDto(BaseModel):
    type: str
    r"""Context type (e.g., tenant, app, workspace)"""

    id: str
    r"""Unique identifier for this context"""

    data: Dict[str, Any]
    r"""Custom data associated with this context"""

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]
    r"""Creation timestamp"""

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]
    r"""Last update timestamp"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .authdto import AuthDto, AuthDtoTypedDict
from .workspacedto import WorkspaceDto, WorkspaceDtoTypedDict
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class UpdateChannelConnectionRequestDtoTypedDict(TypedDict):
    workspace: WorkspaceDtoTypedDict
    auth: AuthDtoTypedDict


class UpdateChannelConnectionRequestDto(BaseModel):
    workspace: WorkspaceDto

    auth: AuthDto



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .emailchanneloverrides import EmailChannelOverrides, EmailChannelOverridesTypedDict
from .severitylevelenum import SeverityLevelEnum
from .stepsoverrides import StepsOverrides, StepsOverridesTypedDict
from .subscriberpayloaddto import SubscriberPayloadDto, SubscriberPayloadDtoTypedDict
from .tenantpayloaddto import TenantPayloadDto, TenantPayloadDtoTypedDict
from novu_py.types import BaseModel
import pydantic
from pydantic import ConfigDict
from typing import Any, Dict, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


class TriggerEventToAllRequestDtoChannelsTypedDict(TypedDict):
    r"""Channel-specific overrides that apply to all steps of a particular channel type. Step-level overrides take precedence over channel-level overrides."""

    email: NotRequired[EmailChannelOverridesTypedDict]
    r"""Email channel specific overrides"""


class TriggerEventToAllRequestDtoChannels(BaseModel):
    r"""Channel-specific overrides that apply to all steps of a particular channel type. Step-level overrides take precedence over channel-level overrides."""

    email: Optional[EmailChannelOverrides] = None
    r"""Email channel specific overrides"""


class TriggerEventToAllRequestDtoOverridesTypedDict(TypedDict):
    r"""This could be used to override provider specific configurations"""

    steps: NotRequired[Dict[str, StepsOverridesTypedDict]]
    r"""This could be used to override provider specific configurations or layout at the step level"""
    channels: NotRequired[TriggerEventToAllRequestDtoChannelsTypedDict]
    r"""Channel-specific overrides that apply to all steps of a particular channel type. Step-level overrides take precedence over channel-level overrides."""
    providers: NotRequired[Dict[str, Dict[str, Any]]]
    r"""Overrides the provider configuration for the entire workflow and all steps"""
    email: NotRequired[Dict[str, Any]]
    r"""Override the email provider specific configurations for the entire workflow"""
    push: NotRequired[Dict[str, Any]]
    r"""Override the push provider specific configurations for the entire workflow"""
    sms: NotRequired[Dict[str, Any]]
    r"""Override the sms provider specific configurations for the entire workflow"""
    chat: NotRequired[Dict[str, Any]]
    r"""Override the chat provider specific configurations for the entire workflow"""
    layout_identifier: NotRequired[str]
    r"""Override the layout identifier for the entire workflow"""
    severity: NotRequired[SeverityLevelEnum]
    r"""Severity of the workflow"""


class TriggerEventToAllRequestDtoOverrides(BaseModel):
    r"""This could be used to override provider specific configurations"""

    model_config = ConfigDict(
        populate_by_name=True, arbitrary_types_allowed=True, extra="allow"
    )
    __pydantic_extra__: Dict[str, Dict[str, Any]] = pydantic.Field(init=False)

    steps: Optional[Dict[str, StepsOverrides]] = None
    r"""This could be used to override provider specific configurations or layout at the step level"""

    channels: Optional[TriggerEventToAllRequestDtoChannels] = None
    r"""Channel-specific overrides that apply to all steps of a particular channel type. Step-level overrides take precedence over channel-level overrides."""

    providers: Optional[Dict[str, Dict[str, Any]]] = None
    r"""Overrides the provider configuration for the entire workflow and all steps"""

    email: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the email provider specific configurations for the entire workflow"""

    push: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the push provider specific configurations for the entire workflow"""

    sms: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the sms provider specific configurations for the entire workflow"""

    chat: Annotated[
        Optional[Dict[str, Any]],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible."
        ),
    ] = None
    r"""Override the chat provider specific configurations for the entire workflow"""

    layout_identifier: Annotated[
        Optional[str],
        pydantic.Field(
            deprecated="warning: ** DEPRECATED ** - This will be removed in a future release, please migrate away from it as soon as possible.",
            alias="layoutIdentifier",
        ),
    ] = None
    r"""Override the layout identifier for the entire workflow"""

    severity: Optional[SeverityLevelEnum] = None
    r"""Severity of the workflow"""

    @property
    def additional_properties(self):
        return self.__pydantic_extra__

    @additional_properties.setter
    def additional_properties(self, value):
        self.__pydantic_extra__ = value  # pyright: ignore[reportIncompatibleVariableOverride]


TriggerEventToAllRequestDtoActorTypedDict = TypeAliasType(
    "TriggerEventToAllRequestDtoActorTypedDict",
    Union[SubscriberPayloadDtoTypedDict, str],
)
r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
If a new actor object is provided, we will create a new subscriber in our system

"""


TriggerEventToAllRequestDtoActor = TypeAliasType(
    "TriggerEventToAllRequestDtoActor", Union[SubscriberPayloadDto, str]
)
r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
If a new actor object is provided, we will create a new subscriber in our system

"""


TriggerEventToAllRequestDtoTenantTypedDict = TypeAliasType(
    "TriggerEventToAllRequestDtoTenantTypedDict", Union[TenantPayloadDtoTypedDict, str]
)
r"""It is used to specify a tenant context during trigger event.
If a new tenant object is provided, we will create a new tenant.

"""


TriggerEventToAllRequestDtoTenant = TypeAliasType(
    "TriggerEventToAllRequestDtoTenant", Union[TenantPayloadDto, str]
)
r"""It is used to specify a tenant context during trigger event.
If a new tenant object is provided, we will create a new tenant.

"""


class TriggerEventToAllRequestDtoContext2TypedDict(TypedDict):
    r"""Rich context object with id and optional data"""

    id: str
    data: NotRequired[Dict[str, Any]]
    r"""Optional additional context data"""


class TriggerEventToAllRequestDtoContext2(BaseModel):
    r"""Rich context object with id and optional data"""

    id: str

    data: Optional[Dict[str, Any]] = None
    r"""Optional additional context data"""


TriggerEventToAllRequestDtoContextTypedDict = TypeAliasType(
    "TriggerEventToAllRequestDtoContextTypedDict",
    Union[TriggerEventToAllRequestDtoContext2TypedDict, str],
)


TriggerEventToAllRequestDtoContext = TypeAliasType(
    "TriggerEventToAllRequestDtoContext",
    Union[TriggerEventToAllRequestDtoContext2, str],
)


class TriggerEventToAllRequestDtoTypedDict(TypedDict):
    name: str
    r"""The trigger identifier associated for the template you wish to send. This identifier can be found on the template page."""
    payload: Dict[str, Any]
    r"""The payload object is used to pass additional information that
    could be used to render the template, or perform routing rules based on it.
    For In-App channel, payload data are also available in <Inbox />
    """
    overrides: NotRequired[TriggerEventToAllRequestDtoOverridesTypedDict]
    r"""This could be used to override provider specific configurations"""
    transaction_id: NotRequired[str]
    r"""A unique identifier for this transaction, we will generated a UUID if not provided."""
    actor: NotRequired[TriggerEventToAllRequestDtoActorTypedDict]
    r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
    If a new actor object is provided, we will create a new subscriber in our system

    """
    tenant: NotRequired[TriggerEventToAllRequestDtoTenantTypedDict]
    r"""It is used to specify a tenant context during trigger event.
    If a new tenant object is provided, we will create a new tenant.

    """
    context: NotRequired[Dict[str, TriggerEventToAllRequestDtoContextTypedDict]]


class TriggerEventToAllRequestDto(BaseModel):
    name: str
    r"""The trigger identifier associated for the template you wish to send. This identifier can be found on the template page."""

    payload: Dict[str, Any]
    r"""The payload object is used to pass additional information that
    could be used to render the template, or perform routing rules based on it.
    For In-App channel, payload data are also available in <Inbox />
    """

    overrides: Optional[TriggerEventToAllRequestDtoOverrides] = None
    r"""This could be used to override provider specific configurations"""

    transaction_id: Annotated[Optional[str], pydantic.Field(alias="transactionId")] = (
        None
    )
    r"""A unique identifier for this transaction, we will generated a UUID if not provided."""

    actor: Optional[TriggerEventToAllRequestDtoActor] = None
    r"""It is used to display the Avatar of the provided actor's subscriber id or actor object.
    If a new actor object is provided, we will create a new subscriber in our system

    """

    tenant: Optional[TriggerEventToAllRequestDtoTenant] = None
    r"""It is used to specify a tenant context during trigger event.
    If a new tenant object is provided, we will create a new tenant.

    """

    context: Optional[Dict[str, TriggerEventToAllRequestDtoContext]] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ButtonTypeEnum(str, Enum):
    r"""Type of button for the action result"""

    PRIMARY = "primary"
    SECONDARY = "secondary"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .resourceoriginenum import ResourceOriginEnum
from .steplistresponsedto import StepListResponseDto, StepListResponseDtoTypedDict
from .steptypeenum import StepTypeEnum
from .workflowstatusenum import WorkflowStatusEnum
from novu_py.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WorkflowListResponseDtoUpdatedByTypedDict(TypedDict):
    r"""User who last updated the workflow"""

    id: str
    r"""User ID"""
    first_name: NotRequired[Nullable[str]]
    r"""User first name"""
    last_name: NotRequired[Nullable[str]]
    r"""User last name"""
    external_id: NotRequired[Nullable[str]]
    r"""User external ID"""


class WorkflowListResponseDtoUpdatedBy(BaseModel):
    r"""User who last updated the workflow"""

    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""User ID"""

    first_name: Annotated[OptionalNullable[str], pydantic.Field(alias="firstName")] = (
        UNSET
    )
    r"""User first name"""

    last_name: Annotated[OptionalNullable[str], pydantic.Field(alias="lastName")] = (
        UNSET
    )
    r"""User last name"""

    external_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="externalId")
    ] = UNSET
    r"""User external ID"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["firstName", "lastName", "externalId"]
        nullable_fields = ["firstName", "lastName", "externalId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class WorkflowListResponseDtoLastPublishedByTypedDict(TypedDict):
    r"""User who last published the workflow"""

    id: str
    r"""User ID"""
    first_name: NotRequired[Nullable[str]]
    r"""User first name"""
    last_name: NotRequired[Nullable[str]]
    r"""User last name"""
    external_id: NotRequired[Nullable[str]]
    r"""User external ID"""


class WorkflowListResponseDtoLastPublishedBy(BaseModel):
    r"""User who last published the workflow"""

    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""User ID"""

    first_name: Annotated[OptionalNullable[str], pydantic.Field(alias="firstName")] = (
        UNSET
    )
    r"""User first name"""

    last_name: Annotated[OptionalNullable[str], pydantic.Field(alias="lastName")] = (
        UNSET
    )
    r"""User last name"""

    external_id: Annotated[
        OptionalNullable[str], pydantic.Field(alias="externalId")
    ] = UNSET
    r"""User external ID"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["firstName", "lastName", "externalId"]
        nullable_fields = ["firstName", "lastName", "externalId"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m


class WorkflowListResponseDtoTypedDict(TypedDict):
    name: str
    r"""Name of the workflow"""
    updated_at: str
    r"""Last updated timestamp"""
    created_at: str
    r"""Creation timestamp"""
    id: str
    r"""Unique database identifier"""
    workflow_id: str
    r"""Workflow identifier"""
    slug: str
    r"""Workflow slug"""
    status: WorkflowStatusEnum
    r"""Status of the workflow"""
    origin: ResourceOriginEnum
    r"""Origin of the layout"""
    step_type_overviews: List[StepTypeEnum]
    r"""Overview of step types in the workflow"""
    steps: List[StepListResponseDtoTypedDict]
    r"""Steps of the workflow"""
    tags: NotRequired[List[str]]
    r"""Tags associated with the workflow"""
    updated_by: NotRequired[Nullable[WorkflowListResponseDtoUpdatedByTypedDict]]
    r"""User who last updated the workflow"""
    last_published_at: NotRequired[Nullable[str]]
    r"""Timestamp of the last workflow publication"""
    last_published_by: NotRequired[
        Nullable[WorkflowListResponseDtoLastPublishedByTypedDict]
    ]
    r"""User who last published the workflow"""
    last_triggered_at: NotRequired[Nullable[str]]
    r"""Timestamp of the last workflow trigger"""
    is_translation_enabled: NotRequired[bool]
    r"""Is translation enabled for the workflow"""


class WorkflowListResponseDto(BaseModel):
    name: str
    r"""Name of the workflow"""

    updated_at: Annotated[str, pydantic.Field(alias="updatedAt")]
    r"""Last updated timestamp"""

    created_at: Annotated[str, pydantic.Field(alias="createdAt")]
    r"""Creation timestamp"""

    id: Annotated[str, pydantic.Field(alias="_id")]
    r"""Unique database identifier"""

    workflow_id: Annotated[str, pydantic.Field(alias="workflowId")]
    r"""Workflow identifier"""

    slug: str
    r"""Workflow slug"""

    status: WorkflowStatusEnum
    r"""Status of the workflow"""

    origin: ResourceOriginEnum
    r"""Origin of the layout"""

    step_type_overviews: Annotated[
        List[StepTypeEnum], pydantic.Field(alias="stepTypeOverviews")
    ]
    r"""Overview of step types in the workflow"""

    steps: List[StepListResponseDto]
    r"""Steps of the workflow"""

    tags: Optional[List[str]] = None
    r"""Tags associated with the workflow"""

    updated_by: Annotated[
        OptionalNullable[WorkflowListResponseDtoUpdatedBy],
        pydantic.Field(alias="updatedBy"),
    ] = UNSET
    r"""User who last updated the workflow"""

    last_published_at: Annotated[
        OptionalNullable[str], pydantic.Field(alias="lastPublishedAt")
    ] = UNSET
    r"""Timestamp of the last workflow publication"""

    last_published_by: Annotated[
        OptionalNullable[WorkflowListResponseDtoLastPublishedBy],
        pydantic.Field(alias="lastPublishedBy"),
    ] = UNSET
    r"""User who last published the workflow"""

    last_triggered_at: Annotated[
        OptionalNullable[str], pydantic.Field(alias="lastTriggeredAt")
    ] = UNSET
    r"""Timestamp of the last workflow trigger"""

    is_translation_enabled: Annotated[
        Optional[bool], pydantic.Field(alias="isTranslationEnabled")
    ] = None
    r"""Is translation enabled for the workflow"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "tags",
            "updatedBy",
            "lastPublishedAt",
            "lastPublishedBy",
            "lastTriggeredAt",
            "isTranslationEnabled",
        ]
        nullable_fields = [
            "updatedBy",
            "lastPublishedAt",
            "lastPublishedBy",
            "lastTriggeredAt",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .digesttimedconfigdto import DigestTimedConfigDto, DigestTimedConfigDtoTypedDict
from .digesttypeenum import DigestTypeEnum
from .digestunitenum import DigestUnitEnum
from enum import Enum
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DigestMetadataDtoUnit(str, Enum):
    r"""Unit of the digest"""

    SECONDS = "seconds"
    MINUTES = "minutes"
    HOURS = "hours"
    DAYS = "days"
    WEEKS = "weeks"
    MONTHS = "months"


class DigestMetadataDtoTypedDict(TypedDict):
    type: DigestTypeEnum
    r"""The Digest Type"""
    digest_key: NotRequired[str]
    r"""Optional key for the digest"""
    amount: NotRequired[float]
    r"""Amount for the digest"""
    unit: NotRequired[DigestMetadataDtoUnit]
    r"""Unit of the digest"""
    events: NotRequired[List[Dict[str, Any]]]
    r"""Optional array of events associated with the digest, represented as key-value pairs"""
    backoff: NotRequired[bool]
    r"""Regular digest: Indicates if backoff is enabled for the regular digest"""
    backoff_amount: NotRequired[float]
    r"""Regular digest: Amount for backoff"""
    backoff_unit: NotRequired[DigestUnitEnum]
    r"""Regular digest: Unit for backoff"""
    update_mode: NotRequired[bool]
    r"""Regular digest: Indicates if the digest should update"""
    timed: NotRequired[DigestTimedConfigDtoTypedDict]
    r"""Configuration for timed digest"""


class DigestMetadataDto(BaseModel):
    type: DigestTypeEnum
    r"""The Digest Type"""

    digest_key: Annotated[Optional[str], pydantic.Field(alias="digestKey")] = None
    r"""Optional key for the digest"""

    amount: Optional[float] = None
    r"""Amount for the digest"""

    unit: Optional[DigestMetadataDtoUnit] = None
    r"""Unit of the digest"""

    events: Optional[List[Dict[str, Any]]] = None
    r"""Optional array of events associated with the digest, represented as key-value pairs"""

    backoff: Optional[bool] = None
    r"""Regular digest: Indicates if backoff is enabled for the regular digest"""

    backoff_amount: Annotated[
        Optional[float], pydantic.Field(alias="backoffAmount")
    ] = None
    r"""Regular digest: Amount for backoff"""

    backoff_unit: Annotated[
        Optional[DigestUnitEnum], pydantic.Field(alias="backoffUnit")
    ] = None
    r"""Regular digest: Unit for backoff"""

    update_mode: Annotated[Optional[bool], pydantic.Field(alias="updateMode")] = None
    r"""Regular digest: Indicates if the digest should update"""

    timed: Optional[DigestTimedConfigDto] = None
    r"""Configuration for timed digest"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Any, Dict
from typing_extensions import Annotated, TypedDict


class ImportMasterJSONRequestDtoTypedDict(TypedDict):
    locale: str
    r"""The locale for which translations are being imported"""
    master_json: Dict[str, Any]
    r"""Master JSON object containing all translations organized by workflow identifier"""


class ImportMasterJSONRequestDto(BaseModel):
    locale: str
    r"""The locale for which translations are being imported"""

    master_json: Annotated[Dict[str, Any], pydantic.Field(alias="masterJson")]
    r"""Master JSON object containing all translations organized by workflow identifier"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from novu_py.types import BaseModel
from typing_extensions import TypedDict


class DeleteMessageResponseDtoStatus(str, Enum):
    r"""The status enum for the performed action"""

    DELETED = "deleted"


class DeleteMessageResponseDtoTypedDict(TypedDict):
    acknowledged: bool
    r"""A boolean stating the success of the action"""
    status: DeleteMessageResponseDtoStatus
    r"""The status enum for the performed action"""


class DeleteMessageResponseDto(BaseModel):
    acknowledged: bool
    r"""A boolean stating the success of the action"""

    status: DeleteMessageResponseDtoStatus
    r"""The status enum for the performed action"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class InBoundParseDomainDtoTypedDict(TypedDict):
    inbound_parse_domain: NotRequired[str]


class InBoundParseDomainDto(BaseModel):
    inbound_parse_domain: Annotated[
        Optional[str], pydantic.Field(alias="inboundParseDomain")
    ] = None
